.. scpper documentation master file, created by
   sphinx-quickstart on Fri Mar 26 20:05:24 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to scpper's documentation!
==================================

.. _ScpperDB API: https://github.com/FiftyNine/ScpperDB

``scpper`` is a Python wrapper for ScpperDB API.

Contents:
 
.. toctree::
   :maxdepth: 2

   api
